from rest_framework import serializers
from arkindex.documents.models import Act, Page
from arkindex.documents.serializers.light import CorpusLightSerializer
from arkindex.documents.serializers.elements import ElementLightSerializer
from arkindex.documents.serializers.ml import TranscriptionSerializer


class PageSearchResultSerializer(serializers.ModelSerializer):
    """
    A page search result with nested transcriptions
    """
    name = serializers.CharField(source='display_name')
    transcriptions = TranscriptionSerializer(many=True, source='transcriptions_results')
    total_transcriptions = serializers.IntegerField()
    parent_paths = serializers.ListField(
        child=serializers.ListField(
            child=ElementLightSerializer()
        ),
    )
    corpus = CorpusLightSerializer()

    class Meta:
        model = Page
        fields = (
            'id',
            'name',
            'transcriptions',
            'total_transcriptions',
            'parent_paths',
            'corpus',
        )


class ActSearchResultSerializer(serializers.ModelSerializer):
    """
    Serialize an act
    """
    transcriptions = TranscriptionSerializer(many=True, source='transcriptions_results')
    total_transcriptions = serializers.IntegerField()
    parent_paths = serializers.ListField(
        child=serializers.ListField(
            child=ElementLightSerializer()
        ),
    )
    corpus = CorpusLightSerializer()

    class Meta:
        model = Act
        fields = (
            'id',
            'name',
            'number',
            'transcriptions',
            'total_transcriptions',
            'parent_paths',
            'corpus',
        )
